API Reference - Core Module
===========================

This section documents the core framework classes and functions.

BasePage
--------

The :class:`~socialseed_e2e.core.base_page.BasePage` class is the foundation for all API testing in socialseed-e2e.

.. automodule:: socialseed_e2e.core.base_page
   :members:
   :undoc-members:
   :show-inheritance:
   :special-members: __init__

Configuration
-------------

.. automodule:: socialseed_e2e.core.config_loader
   :members:
   :undoc-members:
   :show-inheritance:

Models
------

.. automodule:: socialseed_e2e.core.models
   :members:
   :undoc-members:
   :show-inheritance:

Test Orchestrator
-----------------

.. automodule:: socialseed_e2e.core.test_orchestrator
   :members:
   :undoc-members:
   :show-inheritance:

Module Loader
-------------

.. automodule:: socialseed_e2e.core.loaders
   :members:
   :undoc-members:
   :show-inheritance:

Interfaces
----------

.. automodule:: socialseed_e2e.core.interfaces
   :members:
   :undoc-members:
   :show-inheritance:
